@@ -14,12 +14,13 @@ use Lemonldap::NG::Common::PSGI::Constants;
 use Lemonldap::NG::Manager::Constants;
 use Crypt::OpenSSL::RSA;
 use Convert::PEM;
+use URI::URL;
 
 use feature 'state';
 
 extends 'Lemonldap::NG::Manager::Lib';
 
-our $VERSION = '1.9.3';
+our $VERSION = '1.9.7';
 
 #############################
 # I. INITIALIZATION METHODS #
@@ -738,14 +739,13 @@ sub getKey {
     }
     elsif ( $key =~ qr/^$doubleHashKeys$/o ) {
         my @res;
-        if ( defined $value ) {
-            foreach my $host ( sort keys %$value ) {
-                my @tmp;
-                foreach my $k ( sort keys %{ $value->{$host} } ) {
-                    push @tmp, { k => $k, v => $value->{$host}->{$k} };
-                }
-                push @res, { k => $host, h => \@tmp };
+        $value ||= {};
+        foreach my $host ( sort keys %$value ) {
+            my @tmp;
+            foreach my $k ( sort keys %{ $value->{$host} } ) {
+                push @tmp, { k => $k, v => $value->{$host}->{$k} };
             }
+            push @res, { k => $host, h => \@tmp };
         }
         return $self->sendJSONresponse( $req, { value => \@res } );
     }
@@ -1008,15 +1008,20 @@ sub applyConf {
 
     # Parse apply values
     while ( my ( $host, $request ) = each %reloadUrls ) {
-        my ( $method, $vhost, $uri ) =
-          ( $request =~ /^(https?):\/\/([^\/]+)(.*)$/ );
-        unless ($vhost) {
-            $vhost = $host;
-            $uri   = $request;
+        my $r = HTTP::Request->new( 'GET', "http://$host$request");
+        if ($request =~ /^https?:\/\/[^\/]+.*$/) {
+            my $url = URI::URL->new($request);
+            my $targetUrl = $url->scheme."://".$host;
+            $targetUrl .= ":".$url->port if defined ($url->port);
+            $targetUrl .= $url->full_path;
+            $r =
+              HTTP::Request->new( 'GET', $targetUrl,
+                HTTP::Headers->new( Host => $url->host ) );
+            if (defined $url->userinfo && $url->userinfo =~/^([^:]+):(.*)$/) {
+                $r->authorization_basic($1,$2);
+            }
         }
-        my $r =
-          HTTP::Request->new( 'GET', "$method://$host$uri",
-            HTTP::Headers->new( Host => $vhost ) );
+
         my $response = $ua->request($r);
         if ( $response->code != 200 ) {
             $status->{$host} =
